<?php
namespace IntiTest\Db\Connection;

use Doctrine\DBAL\Driver\Connection;
use Inti\Config\Service\ConfigManagerFactory;
use Inti\Container\ContainerFactory;
use Inti\Db\Connection\ConnectionManager;
use IntiTest\Db\ConfigProvider;
use PHPUnit\Framework\TestCase;
use Zend\ConfigAggregator\ArrayProvider;

/**
 * Class ConnectionManagerTest
 *
 * @package IntiTest\Db\Connection
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-db
 */
final class ConnectionFactoryTest extends TestCase
{
    public function testCanCreateConnection()
    {
        $params = [
            'driver' => 'pdo_sqlite',
            'path' => ':memory:',
        ];

        $configFactory = new ConfigManagerFactory();
        $config = $configFactory([
            \Inti\Db\ConfigProvider::class,
            ConfigProvider::class,
            new ArrayProvider([
                ConnectionManager::CONFIG_KEY => [
                    'connections' => [
                        'test' => $params,
                    ],
                ],
            ]),
        ]);

        $containerFactory = new ContainerFactory();
        $container = $containerFactory($config);

        $this->assertTrue($container->has(ConnectionManager::class));

        /** @var ConnectionManager $connections */
        $connections = $container->get(ConnectionManager::class);
        /** @var \Doctrine\DBAL\Connection $connection */
        $connection = $connections->get('test');

        $this->assertInstanceOf(Connection::class, $connection);
        $this->assertEquals($params, $connection->getParams());
    }
}
